@@ -135,6 +135,16 @@ void GlobalSettings::setOutputPath(string path)
   _output_path = path;
 }
 
+string GlobalSettings::getInputPath()
+{
+  return _input_path;
+}
+
+void GlobalSettings::setInputPath(string path)
+{
+  _input_path = path;
+}
+
 string GlobalSettings::getSelectedSolver()
 {
   return _selected_solver;
@@ -182,12 +192,11 @@ string GlobalSettings::getRuntimeLibrarypath()
   return _runtimeLibraryPath;
 }
 
-void GlobalSettings::setAlarmTime(unsigned int t)
+ void GlobalSettings::setAlarmTime(unsigned int t)
 {
   _alarm_time = t;
 }
-
-unsigned int GlobalSettings::getAlarmTime()
+ unsigned int GlobalSettings::getAlarmTime()
 {
   return _alarm_time;
 }
