@@ -38,6 +38,7 @@
  */
 
 // QT Headers
+#include <QObject>
 #include <QtGui/QTextCursor>
 #include <QtGui/QTextDocumentFragment>
 
@@ -98,7 +99,7 @@ namespace IAEX
       }
 
       // 2005-11-21 AF, Added check if the current cell is a
-      // inputcell, set style to 'text' insted.
+      // inputcell, set style to 'text' instead.
       // 2006-02-03 AF, added check if the current cell is a
       // groupcell
       if( style.name() == "input" || style.name() == "Input" || style.name() == "ModelicaInput" ||
@@ -311,7 +312,7 @@ namespace IAEX
       }
       else
       {
-          QMessageBox::warning( 0, "Warning", "No Cells Copied to paste, To paste a cell, select the cells and perform copy", "OK" );
+        QMessageBox::warning( 0, QObject::tr("Warning"), QObject::tr("No cells in clipboard. To paste a cell, select the cells and perform copy."), "OK" );
       }
 
       //2006-01-18 AF, set docuement changed
