@@ -41,14 +41,19 @@
 
 using namespace OMPlot;
 
-PlotCurve::PlotCurve(QString fileName, QString variableName, QString unit, Plot *pParent)
+PlotCurve::PlotCurve(const QString &fileName, const QString &absoluteFilePath, const QString &name, const QString &xVariableName, const QString &yVariableName,
+                     const QString &unit, const QString &displayUnit, Plot *pParent)
   : mCustomColor(false)
 {
-  mName = variableName;
-  mNameStructure = fileName + "." + variableName;
+  mName = name;
+  mXVariable = xVariableName;
+  mYVariable = yVariableName;
+  mNameStructure = fileName + "." + name;
   mFileName = fileName;
+  mAbsoluteFilePath = absoluteFilePath;
   mCustomColor = false;
   setUnit(unit);
+  setDisplayUnit(displayUnit);
   setTitleLocal();
   mpParentPlot = pParent;
   /* set curve width and style */
@@ -58,19 +63,19 @@ PlotCurve::PlotCurve(QString fileName, QString variableName, QString unit, Plot
   setLegendAttribute(QwtPlotCurve::LegendShowLine);
   setLegendIconSize(QSize(30, 30));
 #endif
-}
-
-PlotCurve::~PlotCurve()
-{
-
+  mpPlotDirectPainter = new QwtPlotDirectPainter();
+  mpPointMarker = new QwtPlotMarker();
+  mpPointMarker->attach(mpParentPlot);
+  mpPointMarker->setVisible(false);
+  mpPointMarker->setSymbol(new QwtSymbol(QwtSymbol::Rect, QColor(Qt::red), QColor(Qt::red), QSize(6, 6)));
 }
 
 void PlotCurve::setTitleLocal()
 {
-  if (getUnit().isEmpty()) {
+  if (getDisplayUnit().isEmpty()) {
     QwtPlotItem::setTitle(getName());
   } else {
-    QwtPlotItem::setTitle(getName() + " [" + getUnit() + "]");
+    QwtPlotItem::setTitle(QString("%1 (%2)").arg(getName(), getDisplayUnit()));
   }
 }
 
@@ -133,14 +138,19 @@ void PlotCurve::addXAxisValue(double value)
   mXAxisVector.push_back(value);
 }
 
+void PlotCurve::updateXAxisValue(int index, double value)
+{
+  mXAxisVector.replace(index, value);
+}
+
 const double* PlotCurve::getXAxisVector() const
 {
   return mXAxisVector.data();
 }
 
-QVector<double> PlotCurve::getXAxisData()
+QPair<QVector<double>*, QVector<double>*> PlotCurve::getAxisVectors()
 {
-  return mXAxisVector;
+  return qMakePair(&mXAxisVector, &mYAxisVector);
 }
 
 void PlotCurve::setYAxisVector(QVector<double> vector)
@@ -148,16 +158,16 @@ void PlotCurve::setYAxisVector(QVector<double> vector)
   mYAxisVector = vector;
 }
 
-QVector<double> PlotCurve::getYAxisData()
-{
-  return mYAxisVector;
-}
-
 void PlotCurve::addYAxisValue(double value)
 {
   mYAxisVector.push_back(value);
 }
 
+void PlotCurve::updateYAxisValue(int index, double value)
+{
+  mYAxisVector.replace(index, value);
+}
+
 const double* PlotCurve::getYAxisVector() const
 {
   return mYAxisVector.data();
@@ -173,11 +183,16 @@ void PlotCurve::setFileName(QString fileName)
   mFileName = fileName;
 }
 
-QString PlotCurve::getFileName()
+QString PlotCurve::getFileName() const
 {
   return mFileName;
 }
 
+QString PlotCurve::getAbsoluteFilePath() const
+{
+  return mAbsoluteFilePath;
+}
+
 void PlotCurve::setNameStructure(QString variableName)
 {
   mNameStructure = getFileName() + "." + variableName;
@@ -213,6 +228,22 @@ bool PlotCurve::hasCustomColor()
   return mCustomColor;
 }
 
+/*!
+ * \brief PlotCurve::toggleVisibility
+ * Toggles the curve visibility.
+ */
+void PlotCurve::toggleVisibility()
+{
+  setVisible(!isVisible());
+  QwtText text = title();
+  if (isVisible()) {
+    text.setColor(QColor(Qt::black));
+  } else {
+    text.setColor(QColor(Qt::gray));
+  }
+  setTitle(text);
+}
+
 void PlotCurve::setData(const double* xData, const double* yData, int size)
 {
 #if QWT_VERSION >= 0x060000
@@ -235,3 +266,62 @@ void PlotCurve::updateLegend(QwtLegend *legend) const
   QwtPlotItem::updateLegend(legend);
 }
 #endif
+
+/*!
+ * \brief QwtPlotCurve::closestPoint
+ * Reimplentation of QwtPlotCurve::closestPoint()
+ * Just doesn't fail if first time f < dmin instead we use the first f value to initialize dmin.
+ * \param pos
+ * \param dist
+ * \return
+ */
+int PlotCurve::closestPoint(const QPoint &pos, double *dist) const
+{
+  const size_t numSamples = dataSize();
+  if (plot() == NULL || numSamples <= 0) {
+    return -1;
+  }
+  const QwtSeriesData<QPointF> *series = data();
+
+  const QwtScaleMap xMap = plot()->canvasMap(xAxis());
+  const QwtScaleMap yMap = plot()->canvasMap(yAxis());
+
+  int index = -1;
+  double dmin = 1.0e10;
+
+  for (uint i = 0; i < numSamples; i++) {
+    const QPointF sample = series->sample( i );
+
+    const double cx = xMap.transform(sample.x() ) - pos.x();
+    const double cy = yMap.transform(sample.y() ) - pos.y();
+
+    const double f = qwtSqr(cx) + qwtSqr(cy);
+    if ((i == 0) || (f < dmin)) {
+      index = i;
+      dmin = f;
+    }
+  }
+  if (dist) {
+    *dist = qSqrt(dmin);
+  }
+
+  return index;
+}
+
+/*!
+ * \brief PlotCurve::boundingRect
+ * Reimplentation of QwtPlotCurve::boundingRect() to add a margin.
+ * \return
+ */
+QRectF PlotCurve::boundingRect() const
+{
+  QRectF r = QwtPlotCurve::boundingRect();
+  if (r.isValid()) {
+    /* Ticket:5515 Allow for some margin at the top and bottom of plot windows in OMEdit
+     * We add a margin of 10% to the curves bottom and top to better visualize them.
+     */
+    const double margin = r.height() * 0.1;
+    r.adjust(0, -margin, 0, margin);
+  }
+  return r;
+}
