@@ -34,8 +34,10 @@
 
 #include "Component.h"
 #include "ComRef.h"
+#include "Values.h"
 #include "ResultWriter.h"
 #include "Variable.h"
+
 #include <fmilib.h>
 #include <map>
 #include <pugixml.hpp>
@@ -51,10 +53,11 @@ namespace oms
     ~ComponentFMUME();
 
     static Component* NewComponent(const oms::ComRef& cref, System* parentSystem, const std::string& fmuPath);
-    static Component* NewComponent(const pugi::xml_node& node, System* parentSystem);
+    static Component* NewComponent(const pugi::xml_node& node, System* parentSystem,  const std::string& sspVersion);
     const FMUInfo* getFMUInfo() const {return &(this->fmuInfo);}
 
-    oms_status_enu_t exportToSSD(pugi::xml_node& node) const;
+    oms_status_enu_t exportToSSD(pugi::xml_node& node, pugi::xml_node& ssvNode) const;
+    oms_status_enu_t exportToSSVTemplate(pugi::xml_node& ssvNode);
     oms_status_enu_t instantiate();
     oms_status_enu_t initialize();
     oms_status_enu_t terminate();
@@ -75,6 +78,8 @@ namespace oms
     oms_status_enu_t setInteger(const ComRef& cref, int value);
     oms_status_enu_t setReal(const ComRef& cref, double value);
 
+    oms_status_enu_t deleteStartValue(const ComRef& cref);
+
     oms_status_enu_t registerSignalsForResultFile(ResultWriter& resultFile);
     oms_status_enu_t updateSignals(ResultWriter& resultWriter);
     oms_status_enu_t addSignalsToResults(const char* regex);
@@ -120,15 +125,15 @@ namespace oms
     std::vector<Variable> inputs;
     std::vector<Variable> outputs;
     std::vector<Variable> parameters;
+    std::vector<Variable> calculatedParameters;
     std::vector<bool> exportVariables;
 
-    std::map<ComRef, double> realStartValues;  ///< parameters and start values defined before instantiating the FMU
-    std::map<ComRef, int> integerStartValues;  ///< parameters and start values defined before instantiating the FMU
-    std::map<ComRef, bool> booleanStartValues; ///< parameters and start values defined before instantiating the FMU
+    Values values; ///< start values defined before instantiating the FMU and external inputs defined after initialization
 
     std::unordered_map<unsigned int /*result file var ID*/, unsigned int /*allVariables ID*/> resultFileMapping;
 
     std::map<fmi2_value_reference_t, oms_fault_type_t> fib;  ///< fault injection blocks
+    oms::ComRef getValidCref(ComRef cref);
   };
 }
 
